MonotonicAffineTransformationInteraction
========================================

.. currentmodule:: pykeen.nn.modules

.. autoclass:: MonotonicAffineTransformationInteraction
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~MonotonicAffineTransformationInteraction.forward
      ~MonotonicAffineTransformationInteraction.reset_parameters

   .. rubric:: Methods Documentation

   .. automethod:: forward
   .. automethod:: reset_parameters
